# Wagtail Newsletter

Turn Wagtail pages into newsletters.

[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![PyPI version](https://badge.fury.io/py/wagtail-newsletter.svg)](https://badge.fury.io/py/wagtail-newsletter)
[![Newsletter CI](https://github.com/wagtail/wagtail-newsletter/actions/workflows/test.yml/badge.svg)](https://github.com/wagtail/wagtail-newsletter/actions/workflows/test.yml)

## Links

- [Documentation](https://wagtail-newsletter.readthedocs.io)
- [Changelog](https://github.com/wagtail/wagtail-newsletter/blob/main/CHANGELOG.md)
- [Contributing](https://github.com/wagtail/wagtail-newsletter/blob/main/CONTRIBUTING.md)
- [Discussions](https://github.com/wagtail/wagtail-newsletter/discussions)
- [Security](https://github.com/wagtail/wagtail-newsletter/security)

## Supported versions

- Python (3.8, 3.9, 3.10, 3.11, 3.12)
- Django (4.2, 5.0)
- Wagtail (5.2, 6.1, 6.2)

## Installation

See https://wagtail-newsletter.readthedocs.io/en/stable/installation.html.

## Sample project

There is a sample project in the [demo](./demo/) subdirectory. Check out its README for instructions on how to get it running.
